@@ -27,8 +27,6 @@
 #include "gkm-object.h"
 #include "gkm-types.h"
 
-#include "egg/egg-bytes.h"
-
 #define GKM_FACTORY_CERTIFICATE            (gkm_certificate_get_factory ())
 
 #define GKM_TYPE_CERTIFICATE               (gkm_certificate_get_type ())
@@ -60,7 +58,7 @@ gboolean                   gkm_certificate_calc_category          (GkmCertificat
 
 GkmCertificateKey*         gkm_certificate_get_public_key         (GkmCertificate *self);
 
-EggBytes *                 gkm_certificate_get_extension          (GkmCertificate *self,
+GBytes *                   gkm_certificate_get_extension          (GkmCertificate *self,
                                                                    GQuark oid,
                                                                    gboolean *critical);
 
