@@ -34,7 +34,7 @@
 #include <glib-object.h>
 
 /* Module callbacks for secure memory */
-EGG_SECURE_GLIB_DEFINITIONS ();
+EGG_SECURE_DEFINE_GLIB_GLOBALS ();
 
 CK_RV
 C_GetFunctionList (CK_FUNCTION_LIST_PTR_PTR list)
